==> haskell-bytestring-progress-1.4-147.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-J61so6qu5etDwvMK3gRlI1
key:                  bytestring-progress-1.4-J61so6qu5etDwvMK3gRlI1
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  ca3016c2f705505284c0ee7d617c99c2
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-J61so6qu5etDwvMK3gRlI1
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    terminal-progress-bar-0.4.2-FkwhEaBBbmRE9tdVAb2Wvt text-2.0.2
    time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-progress-1.4-148-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-1hJS2Q6EhmHIdNFKiusA3W
key:                  bytestring-progress-1.4-1hJS2Q6EhmHIdNFKiusA3W
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  112f79a5e31cdaff68983c3631e80717
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-1hJS2Q6EhmHIdNFKiusA3W
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    terminal-progress-bar-0.4.2-7VMSrzvH1e0GhBamfD7eyr text-2.0.2
    time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
